@@ -22,7 +22,7 @@
 #include <version.h>
 #include <torrent/job.h>
 
-K_PLUGIN_FACTORY_WITH_JSON(KGetFactory, "kget_bittorrentfactory.json", registerPlugin<BTTransferFactory>();)
+K_PLUGIN_CLASS_WITH_JSON(BTTransferFactory, "kget_bittorrentfactory.json")
 
 BTTransferFactory::BTTransferFactory(QObject *parent, const QVariantList &args)
   : TransferFactory(parent, args)
